<?php

namespace App\Service;

use App\Entity\User;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Symfony\Component\Security\Csrf\TokenGenerator\TokenGeneratorInterface;

/**
 * Agir sur les utilisateurs
 */
class UserManager
{
    protected $em;
    protected $passwordEncoder;
    protected $tokenGenerator;
    /**
     * UserManager constructor.
     * @param EntityManagerInterface $em
     */
    public function __construct(EntityManagerInterface $em, UserPasswordEncoderInterface $passwordEncoder, TokenGeneratorInterface $tokenGenerator)
    {
        $this->em = $em;
        $this->passwordEncoder = $passwordEncoder;
        $this->tokenGenerator = $tokenGenerator;
    }

    public function createUser($username, $password, $nom, $prenom, $mail, $roles, $activated)
    {
        $user = new User();
        $user->setUsername($username);
        $user->setPrenom($prenom);
        $user->setNom($nom);
        $user->setMail($mail);
        $user->setRoles($roles);
        $user->setActivated($activated);
        $user->setPassword($password);
        $this->enregistrerUser($user);
    }

    public function register(User $user)
    {
        $user->setActivated(false);
        $user->setRoles(array('ROLE_USER'));
        $this->enregistrerUser($user);
    }


    public function resetPassword(User $user)
    {
        $user->setActivated($user);
        $this->enregistrerUser($user);
    }
    public function enregistrerUser (User $user)
    {
        $encoded = $this->passwordEncoder->encodePassword($user, $user->getPassword());
        $user->setPassword($encoded);
        $this->generateToken($user);
        $this->em->persist($user);
        $this->em->flush();
    }

    public function editUser ()
    {
        $this->em->flush();
    }

    public function removeUser(User $user)
    {
        $this->em->remove($user);
        $this->em->flush();
    }

    public function generateToken(User $user)
    {
        $user->setToken($this->tokenGenerator->generateToken());
    }

}